#!/bin/sh
# Copyright (c) 2002-2008 KONICA MINOLTA BUSINESS TECHNOLOGIES, INC. All rights reserved.
#
# Print Utility filter for tradional BSD lpr/lpd systems, which don't
# support passing lp/lpr command line args through to the filter,
# so they are passed via a file instead.
#
# The file is /tmp/kp.<printer>.<id>
#
# The -w command line arg is used to pass the id into the filter.
# 

OS=`uname -s`
case $OS in
  OpenBSD | FreeBSD | NetBSD)
    filterDir="/usr/local/libexec/kmpu";
    ;;

  Linux)

    filterDir="/usr/lib/kmpu";
    ;;

  *)
    echo "Error unsupported Operating System.";
    exit 1;
    ;;
esac

#
# Look through the options for the -w option
#
while [ $# -ne 0 ]
do
  case $1 in
  -w*)
	# Grab the id
        fid=`getopt w: $1 | awk '{print $2}'`
	;;
  -n)
	# Grab the user
        user=$2
	;;
  -j)
	# Grab the title
        title=$2
	;;
  *)
	;;
  esac
  shift
done

filterFile=`find /tmp -name 'kp*.'$fid -print 2>/dev/null`

if [ $filterFile -a -s $filterFile ]
then
  filterArgs=`cat $filterFile`
  # Get the printer, which is always the first arg
  lprinterArg=`echo $filterArgs | awk '{print $1}'`
  lprinter=`getopt d: $lprinterArg | awk '{print $2}'`
else
  # Get the printer from current directory name
  lprinter=`basename $PWD`
  filterArgs="-d$lprinter -title=$title"
fi
#
# Lookup the remote printer associated to this printer
#
line=`grep $lprinter /etc/lp/printutility.remote`
lpcmd=`sh -c 'echo $1 $2' $line`

#
# Look through the options for the T option
#
filetype="NOTSET"
atype=`echo $filterArgs | grep -c "T=ka"`
if [ $atype -eq 1 ]
then
  filetype="ASCII"
else
  ptype=`echo $filterArgs | grep -c "T=kps"`
  if [ $ptype -eq 1 ]
  then
    filetype="PS"
  fi
fi

#
# Process stdin using the appropriate filters
#
kpfilter="$filterDir/kpf $filterArgs -user=$user"
asciifilter="$filterDir/kaps $filterArgs -user=$user"

case "$filetype" in
=ka)
    # ASCII - pump each file through kaps first 
    cat | $asciifilter | $kpfilter | $lpcmd
    ;;

=kps)
    # PostScript - just use filter to insert features
    cat | $kpfilter | $lpcmd
    ;;

*)
    # Unspecified; save stdin in temp file and look at first line
    tempfilename=`/usr/bin/kptmpnam`
    cat > $tempfilename
    read line < $tempfilename
    case "$line" in
    %!*)
	# PostScript file
	cat $tempfilename | $kpfilter | $lpcmd
	;;

    *)
	# ASCII file
	cat $tempfilename | $asciifilter | $kpfilter | $lpcmd
	;;
    esac
    ;;
esac
exit 0
